/* gfsconfig.h
 *
 * This is a generated file.  Please modify `configure.in'
 */

#ifndef GFSCONFIG_H
#define GFSCONFIG_H

#define GFS_MODULES_DIR "/home/popinet/adds/lib/gerris"
#define GFS_HAS_MODULES 1


#endif /* GFSCONFIG_H */
